==> haskell-aeson-warning-parser-0.1.1-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-Ia9JnQpA6zX3Jok7mbLBki
key:                  aeson-warning-parser-0.1.1-Ia9JnQpA6zX3Jok7mbLBki
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  6dc17562031fee297bcad413f8a1e13b
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-Ia9JnQpA6zX3Jok7mbLBki
depends:
    aeson-2.1.2.1-FurzwiqHIOZ8NUBnR3RWtD base-4.17.2.1 containers-0.6.7
    generic-deriving-1.14.6-IdkBRCRyOIuHPRaIPZ6zin
    rio-0.1.22.0-5Djq7uaeUXM2gIOiSDk0xX
    rio-prettyprint-0.1.8.0-11EryedogRd1UFIv6tpkz9 text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-3ZBRQjn1NdW5zFXXpEAC63

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-warning-parser-0.1.1-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-aeson-warning-parser.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 aeson-warning-parser
version:              0.1.1
visibility:           public
id:                   aeson-warning-parser-0.1.1-GLQDukGUjaI9ljjLBkPinj
key:                  aeson-warning-parser-0.1.1-GLQDukGUjaI9ljjLBkPinj
license:              BSD-3-Clause
copyright:            2018-2023 FP Complete
maintainer:           Mike Pilgrem <public@pilgrem.com>
author:               Michael Snoyman
homepage:
    https://github.com/commercialhaskell/aeson-warning-parser#readme

synopsis:
    Library providing JSON parser that warns about unexpected fields in objects.

description:
    Please see the README on GitHub at <https://github.com/commercialhaskell/aeson-warning-parser#readme>

category:             JSON
abi:                  7a36cc90d726c79770137935403e461d
exposed:              True
exposed-modules:      Data.Aeson.WarningParser
hidden-modules:       Paths_aeson_warning_parser
import-dirs:          /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/aeson-warning-parser-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-aeson-warning-parser
hs-libraries:         HSaeson-warning-parser-0.1.1-GLQDukGUjaI9ljjLBkPinj
depends:
    aeson-2.1.2.1-8PRfz0Kg6mwK2TOn7o5BkY base-4.17.2.1 containers-0.6.7
    generic-deriving-1.14.6-BdNL5LYX8Lg7vHbU8xJokt
    rio-0.1.22.0-7tVdzEvIPAFs50VPojjR8
    rio-prettyprint-0.1.8.0-IhTx83FATQe8NwCSkrBu6O text-2.0.2
    transformers-0.5.6.2
    unordered-containers-0.2.20-8Q4WKXtMGLf6eJrIPiNhPJ

haddock-interfaces:
    /usr/share/doc/haskell-aeson-warning-parser/html/aeson-warning-parser.haddock

haddock-html:         /usr/share/doc/haskell-aeson-warning-parser/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
